tokenizer\_tools.converter package
==================================

Submodules
----------

tokenizer\_tools.converter.conllx\_to\_rasa module
--------------------------------------------------

.. automodule:: tokenizer_tools.converter.conllx_to_rasa
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.converter.conllz\_to\_offset module
----------------------------------------------------

.. automodule:: tokenizer_tools.converter.conllz_to_offset
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.converter.offset\_to\_sentence module
------------------------------------------------------

.. automodule:: tokenizer_tools.converter.offset_to_sentence
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.converter.sentence\_to\_offset module
------------------------------------------------------

.. automodule:: tokenizer_tools.converter.sentence_to_offset
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tokenizer_tools.converter
   :members:
   :undoc-members:
   :show-inheritance:
